##
# Copyright (c) 2010-2014 Apple Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
##
from __future__ import print_function

import eventkitframework as EventKit
from Cocoa import NSDate

store = EventKit.EKEventStore.alloc().init()
calendars = store.calendarsForEntityType_(0)
print(calendars)
raise SystemExit

predicate = store.predicateForEventsWithStartDate_endDate_calendars_(
     NSDate.date(), NSDate.distantFuture(),
     [calendars[2]])
print(store.eventsMatchingPredicate_(predicate))
